%  Script file: p_resistor.m
%
%  Purpose: 
%    To plot the power consumed by a resistor as a function
%    of the voltage across the resistor on both a linear and
%    a log scale. 
%
%  Record of revisions:
%      Date       Programmer          Description of change
%      ====       ==========          =====================
%    11/14/07    S. J. Chapman        Original code 
%
% Define variables:
%   ir    -- Current in the resistor (A)
%   pr    -- Power in the resistor (W)
%   r     -- Resistance of resistor (ohms)
%   vr    -- Voltage across the resistor (V)
%   vr_db -- Voltage across the resistor (dBW)

% Set the resistance
r = 1000;

% Create array of voltage across the resistor 
vr = 1:200;

% Calculate the current flow through the resistor
ir = vr / r;

% Calculate the power consumed by the resistor in watts
pr = ir .* vr;

% Calculate the power consumed by the resistor in dBW
pr_db = 10 * log10(pr);

% Plot linear power
figure(1);
plot(vr,pr);
title('Plot of power in watts vs voltage in volts');
xlabel('Voltage (V)');
ylabel('Power (watts)');
grid on;

% Plot log power
figure(2);
plot(vr,pr_db);
title('Plot of power in dBW vs voltage in volts');
xlabel('Voltage (V)');
ylabel('Power (dBW)');
grid on;
