%  Script file: radio2.m
%
%  Purpose: 
%    To plot the frequency response of a radio receiver. 
%
%  Record of revisions:
%      Date       Programmer          Description of change
%      ====       ==========          =====================
%    11/14/07    S. J. Chapman        Original code 
%
% Define variables:
%   c         -- Capacitance (F)
%   freq      -- Resonant frequency (Hz)
%   l         -- Inductance (H)
%   r         -- resistance (ohms)
%   v         -- output viltage (V)
%   v0        -- input voltage (V)
%   w         -- Angular frequency (rad/s)

% Initialise values
c  = 0.1e-9;
l  = 0.25e-3;
r  = 50;
v0 = 10e-3;

% Create an array of frequencies centered on 1 MHz,
% which is the resonant frequency
freq = (0.7:0.001:1.3) * 1e6;

% Calculate w
w = 2 * pi * freq;

% Calculate output voltage
v =  v0 .* r ./ sqrt( r^2 + (w.*l - 1./(w.*c)).^2 );

% Plot on linear scale
plot(freq,v);
title('Plot of output voltage vs frequency');
xlabel('Frequency (Hz)');
ylabel('Voltage (V)');
grid on;
